==> schemacrawler-16.19.11-1.src.tar.gz: SchemaCrawler-16.19.11/schemacrawler-website/src/site/markdown/license.md <==
# SchemaCrawler License

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

## License Without JDBC Drivers

SchemaCrawler and the accompanying materials are made available under the terms of any one
of these licenses, as long as you have downloaded SchemaCrawler that is not bundled with JDBC drivers:

- [Eclipse Public License v1.0](https://www.eclipse.org/legal/epl-v10.html)
- ![GNU General Public License v3](https://www.gnu.org/graphics/gplv3-88x31.png) 
 [GNU General Public License v3](https://www.gnu.org/licenses/gpl-3.0.en.html) 
- ![GNU Lesser General Public License v3](https://www.gnu.org/graphics/lgplv3-88x31.png) 
 [GNU Lesser General Public License v3](https://www.gnu.org/licenses/lgpl-3.0.en.html).

In order to download and use SchemaCrawler under one of the licenses above, you should
have obtained the SchemaCrawler jar files from the 
[The Central Repository](https://search.maven.org/search?q=g:us.fatehi%20a:schemacrawler*), 
or built them yourself from the source code.


## License With JDBC Drivers

SchemaCrawler and the accompanying materials are also distributed bundled with JDBC drivers for 
different database systems. These [bundled 
distributions](database-support.html) are distributed only under the 
![GNU General Public License  v3](https://www.gnu.org/graphics/gplv3-88x31.png) 
[GNU General Public License v3](https://www.gnu.org/licenses/gpl-3.0.en.html) 
in order to be compatible with the licenses of the JDBC drivers. The 
JDBC drivers that are packaged with these SchemaCrawler distributions 
are in their binary form, and retain their original license. 

If you download and use the [main SchemaCrawler distribution](https://github.com/schemacrawler/SchemaCrawler/releases/),
or the the [SchemaCrawler Docker image](https://hub.docker.com/r/schemacrawler/schemacrawler/),
you are downloading and using SchemaCrawler distributed along with open-source JDBC drivers.
In this case, you are licensed to use SchemaCrawler only under the 
[GNU General Public License v3](https://www.gnu.org/licenses/gpl-3.0.en.html).


## Custom or Commercial License

If you need to use SchemaCrawler with customized licensing terms, or with a commercial license, please see 
the [Consulting page](consulting.html), and obtain a Professional Support Package.

==> schemacrawler-16.22.1-2.src.tar.gz: SchemaCrawler-16.22.1/schemacrawler-website/src/site/markdown/license.md <==
# SchemaCrawler License

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

## License Without JDBC Drivers

SchemaCrawler and the accompanying materials are made available under the terms of any one
of these licenses, as long as you have downloaded SchemaCrawler that is not bundled with JDBC drivers:

- [Eclipse Public License v1.0](https://www.eclipse.org/legal/epl-v10.html)
- ![GNU General Public License v3](https://www.gnu.org/graphics/gplv3-88x31.png) 
 [GNU General Public License v3](https://www.gnu.org/licenses/gpl-3.0.en.html) 
- ![GNU Lesser General Public License v3](https://www.gnu.org/graphics/lgplv3-88x31.png) 
 [GNU Lesser General Public License v3](https://www.gnu.org/licenses/lgpl-3.0.en.html).

In order to download and use SchemaCrawler under one of the licenses above, you should
have obtained the SchemaCrawler jar files from the 
[The Central Repository](https://central.sonatype.com/search?q=us.fatehi.schemacrawler&sort=name), 
or built them yourself from the source code.


## License With JDBC Drivers

SchemaCrawler and the accompanying materials are also distributed bundled with JDBC drivers for 
different database systems. These [bundled 
distributions](database-support.html) are distributed only under the 
![GNU General Public License  v3](https://www.gnu.org/graphics/gplv3-88x31.png) 
[GNU General Public License v3](https://www.gnu.org/licenses/gpl-3.0.en.html) 
in order to be compatible with the licenses of the JDBC drivers. The 
JDBC drivers that are packaged with these SchemaCrawler distributions 
are in their binary form, and retain their original license. 

If you download and use the [main SchemaCrawler distribution](https://www.schemacrawler.com/downloads.html#running-examples-locally/),
or the the [SchemaCrawler Docker image](https://hub.docker.com/r/schemacrawler/schemacrawler/),
you are downloading and using SchemaCrawler distributed along with open-source JDBC drivers.
In this case, you are licensed to use SchemaCrawler only under the 
[GNU General Public License v3](https://www.gnu.org/licenses/gpl-3.0.en.html).


## Custom or Commercial License

If you need to use SchemaCrawler with customized licensing terms, or with a commercial license, please see 
the [Consulting page](consulting.html), and obtain a Professional Support Package.
